@@ -1,81 +1,9 @@
 #!/usr/bin/env python
 from libnmap.diff import NmapDiff
+from libnmap.objects.os import NmapOSFingerprint
 
 
 class NmapHost(object):
-    """
-        NmapHost is a class representing a host object of NmapReport
-    """
-    class NmapOSFingerprint(object):
-        """
-            NmapOSFingerprint is a easier API for using os fingerprinting
-        """
-        def __init__(self, osfp_data):
-            self.__fingerprint = ''
-            self.__osmatch = ''
-            self.__osclass = ''
-            if 'osfingerprint' in osfp_data:
-                self.__fingerprint = osfp_data['osfingerprint']
-
-            __sortfct = lambda osent: int(osent['accuracy'])
-            if 'osmatch' in osfp_data:
-                try:
-                    self.__osmatch = sorted(osfp_data['osmatch'],
-                                            key=__sortfct,
-                                            reverse=True)
-                except (KeyError, TypeError):
-                    self.__osmatch = []
-
-            if 'osclass' in osfp_data:
-                try:
-                    self.__osclass = sorted(osfp_data['osclass'],
-                                            key=__sortfct,
-                                            reverse=True)
-                except (KeyError, TypeError):
-                    self.__osclass = []
-
-        def osmatch(self, min_accuracy=90):
-            os_array = []
-            for match_entry in self.__osmatch:
-                try:
-                    if int(match_entry['accuracy']) >= min_accuracy:
-                        os_array.append(match_entry['name'])
-                except (KeyError, TypeError):
-                    pass
-            return os_array
-
-        def osclass(self, min_accuracy=90):
-            os_array = []
-            for osclass_entry in self.__osclass:
-                try:
-                    if int(osclass_entry['accuracy']) >= min_accuracy:
-                        _relevantkeys = ['type', 'vendor', 'osfamily', 'osgen']
-                        _ftstr = "|".join([vkey + ": " + osclass_entry[vkey]
-                                          for vkey in osclass_entry
-                                          if vkey in _relevantkeys])
-                        os_array.append(_ftstr)
-                except (KeyError, TypeError):
-                    pass
-            return os_array
-
-        def fingerprint(self):
-            return self.__fingerprint
-
-        def __repr__(self):
-            _fmtstr = ''
-            if len(self.osmatch()):
-                _fmtstr += "OS:\r\n"
-                for _osmline in self.osmatch():
-                    _fmtstr += "  {0}\r\n".format(_osmline)
-            elif len(self.osclass()):
-                _fmtstr += "OS CLASS:\r\n"
-                for _oscline in self.osclass():
-                    _fmtstr += "  {0}\r\n".format(_oscline)
-            elif len(self.fingerprint()):
-                _fmtstr += "OS FINGERPRINT:\r\n"
-                _fmtstr += "  {0}".format(self.fingerprint())
-            return _fmtstr
-
     """
         NmapHost is a class representing a host object of NmapReport
     """
@@ -101,9 +29,12 @@ class NmapHost(object):
         self._services = services if services is not None else []
         self._extras = extras if extras is not None else {}
         self._osfingerprinted = False
+        self.os = None
         if 'os' in self._extras:
-            self.os = self.NmapOSFingerprint(self._extras['os'])
+            self.os = NmapOSFingerprint(self._extras['os'])
             self._osfingerprinted = True
+        else:
+            self.os = NmapOSFingerprint({})
 
         self._ipv4_addr = None
         self._ipv6_addr = None
@@ -269,6 +200,17 @@ class NmapHost(object):
         """
         self._status = statusdict
 
+    def is_up(self):
+        """
+            method to determine if host is up or not
+
+            :return: bool
+        """
+        rval = False
+        if self.status == 'up':
+            rval = True
+        return rval
+
     @property
     def hostnames(self):
         """
@@ -336,16 +278,11 @@ class NmapHost(object):
             Returns an array of possible OS class detected during
             the OS fingerprinting.
 
-            Example [{'accuracy': '96', 'osfamily': 'embedded',
-                      'type': 'WAP', 'vendor': 'Netgear'}, {...}]
-
-            :return: dict describing the OS class detected and the accuracy
+            :return: Array of NmapOSClass objects
         """
         rval = []
-        try:
-            rval = self._extras['os']['osclass']
-        except (KeyError, TypeError):
-            pass
+        if self.os is not None:
+            rval = self.os.osclasses
         return rval
 
     def os_match_probabilities(self):
@@ -353,14 +290,11 @@ class NmapHost(object):
             Returns an array of possible OS match detected during
             the OS fingerprinting
 
-            :return: dict describing the OS version detected and the accuracy
+            :return: array of NmapOSMatches objects
         """
-
         rval = []
-        try:
-            rval = self._extras['os']['osmatch']
-        except (KeyError, TypeError):
-            pass
+        if self.os is not None:
+            rval = self.os.osmatches
         return rval
 
     @property
@@ -380,10 +314,8 @@ class NmapHost(object):
             :return: string
         """
         rval = ''
-        try:
-            rval = self._extras['os']['osfingerprint']
-        except (KeyError, TypeError):
-            pass
+        if self.os is not None:
+            rval = self.os.fingerprints.join("\n")
         return rval
 
     def os_ports_used(self):
